@@ -9,7 +9,7 @@ import logging
 import mimetypes
 import time
 from pathlib import Path
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional, Type, Union
 
 import telegram.ext
 import validators
@@ -34,11 +34,18 @@ class TelegramMenuSession:
     # delays in seconds
     READ_TIMEOUT = 6
     CONNECT_TIMEOUT = 7
+    START_MESSAGE = "start"
 
-    start_message_class: type
+    def __init__(self, api_key: str, start_message: str = START_MESSAGE) -> None:
+        """
+        Initialize the session object.
 
-    def __init__(self, api_key: str) -> None:
-        """Initialize TelegramMenuSession class."""
+        Parameters
+        ----------
+        api_key: Telegram bot API key
+        start_message: text used to start a session, e.g. /start
+
+        """
         if not isinstance(api_key, str):
             raise KeyError("API_KEY must be a string!")
 
@@ -57,27 +64,51 @@ class TelegramMenuSession:
 
         self._api_key = api_key
         self.sessions: List[NavigationHandler] = []
-        self.start_message_args = None
+        self.start_message_class: Optional[Type[BaseMessage]] = None
+        self.start_message_args: Optional[List[Any]] = None
+        self.navigation_handler_class: Optional[Type["NavigationHandler"]] = None
 
         # on different commands - answer in Telegram
-        dispatcher.add_handler(CommandHandler("start", self._send_start_message))
+        dispatcher.add_handler(CommandHandler(start_message, self._send_start_message))
         dispatcher.add_handler(MessageHandler(telegram.ext.Filters.text, self._button_select_callback))
         dispatcher.add_handler(CallbackQueryHandler(self._button_inline_select_callback))
         dispatcher.add_handler(telegram.ext.PollAnswerHandler(self._poll_answer))
         dispatcher.add_error_handler(self._msg_error_handler)
 
-    def start(self, start_message_class: type, start_message_args: Any = None, idle: bool = False) -> None:
-        """Set start message and run dispatcher."""
+    def start(
+        self,
+        start_message_class: Type[BaseMessage],
+        start_message_args: Optional[List[Any]] = None,
+        polling: bool = True,
+        idle: bool = False,
+        navigation_handler_class: Optional[Type["NavigationHandler"]] = None,
+    ) -> None:
+        """
+        Set the start message and run the dispatcher.
+
+        Parameters
+        ----------
+        start_message_class: class used to create start message
+        start_message_args: optional arguments passed to the start class
+        polling: if True, start polling updates from Telegram
+        idle: if True, blocks until one of the signals are received and stops the updater
+        navigation_handler_class: optional class used to extend the base NavigationHandler
+
+        """
         self.start_message_class = start_message_class
         self.start_message_args = start_message_args
+        self.navigation_handler_class = navigation_handler_class or NavigationHandler
         if not issubclass(start_message_class, BaseMessage):
             raise AttributeError("start_message_class must be a BaseMessage!")
         if start_message_args is not None and not isinstance(start_message_args, list):
             raise AttributeError("start_message_args is not a list!")
+        if not issubclass(self.navigation_handler_class, NavigationHandler):
+            raise AttributeError("navigation_handler_class must be a NavigationHandler!")
 
         if not self.scheduler.running:
             self.scheduler.start()
-        self.updater.start_polling()
+        if polling:
+            self.updater.start_polling()
         if idle:
             self.updater.idle()
 
@@ -86,12 +117,14 @@ class TelegramMenuSession:
         chat = update.effective_chat
         if chat is None:
             raise AttributeError("Chat object was not created")
-        session = NavigationHandler(self._api_key, chat, self.scheduler)
+        if self.navigation_handler_class is None:
+            raise AttributeError("Navigation Handler class not defined")
+        session = self.navigation_handler_class(self._api_key, chat, self.scheduler)
         self.sessions.append(session)
         if self.start_message_class is None:
             raise AttributeError("Message class not defined")
         if self.start_message_args is not None:
-            start_message = self.start_message_class(session, self.start_message_args)
+            start_message = self.start_message_class(session, message_args=self.start_message_args)
         else:
             start_message = self.start_message_class(session)
         session.goto_menu(start_message)
@@ -157,6 +190,15 @@ class TelegramMenuSession:
                 messages.append(msg)
         return messages
 
+    def broadcast_sticker(self, sticker_path: str, notification: bool = True) -> List[telegram.Message]:
+        """Broadcast picture to all sessions."""
+        messages = []
+        for session in self.sessions:
+            msg = session.send_sticker(sticker_path, notification=notification)
+            if msg is not None:
+                messages.append(msg)
+        return messages
+
 
 class NavigationHandler:
     """Navigation handler for Telegram application."""
@@ -201,12 +243,16 @@ class NavigationHandler:
         if len(self._menu_queue) >= 2 and self._menu_queue[-1].has_expired():
             self.goto_home()
 
+    def delete_message(self, message_id: int) -> None:
+        """Delete a message from its id."""
+        self._bot.delete_message(chat_id=self.chat_id, message_id=message_id)
+
     def _delete_queued_message(self, message: BaseMessage) -> None:
         """Delete a message, remove from queue."""
         message.kill_message()
         if message in self._message_queue:
             self._message_queue.remove(message)
-            self._bot.delete_message(chat_id=self.chat_id, message_id=message.message_id)
+            self.delete_message(message.message_id)
         del message
 
     def goto_menu(self, menu_message: BaseMessage) -> int:
@@ -370,7 +416,7 @@ class NavigationHandler:
             logger.error(f"No button found with label {label_action}, return")
             return
 
-        if button_found.btype == ButtonType.PICTURE:
+        if button_found.btype in [ButtonType.PICTURE, ButtonType.STICKER]:
             # noinspection PyTypeChecker
             self._bot.send_chat_action(chat_id=self.chat_id, action=ChatAction.UPLOAD_PHOTO)
         elif button_found.btype == ButtonType.MESSAGE:
@@ -392,10 +438,13 @@ class NavigationHandler:
 
         # send picture if custom label found
         if button_found.btype == ButtonType.PICTURE:
-            picture_path = action_status
-            self.send_photo(picture_path, notification=button_found.notification)
+            self.send_photo(picture_path=action_status, notification=button_found.notification)
             self._bot.answer_callback_query(callback_id, text="Picture sent!")
             return
+        if button_found.btype == ButtonType.STICKER:
+            self.send_sticker(sticker_path=action_status, notification=button_found.notification)
+            self._bot.answer_callback_query(callback_id, text="Sticker sent!")
+            return
         if button_found.btype == ButtonType.MESSAGE:
             self.send_message(action_status, notification=button_found.notification)
             self._bot.answer_callback_query(callback_id, text="Message sent!")
@@ -406,6 +455,24 @@ class NavigationHandler:
         message.is_alive()
         self.edit_message(message)
 
+    @staticmethod
+    def _sticker_check_replace(sticker_path: str) -> Union[str, bytes]:
+        """Check if sticker is correct file type."""
+        try:
+            if not sticker_path.lower().endswith(".webp"):
+                raise ValueError("Sticker has no .webp format")
+            if validators.url(sticker_path):
+                # todo: add check if url exists
+                return sticker_path
+            if Path(sticker_path).is_file() and imghdr.what(sticker_path):
+                with open(sticker_path, "rb") as file_h:
+                    return file_h.read()
+            raise ValueError("Path is not a picture")
+        except ValueError:
+            url_default = f"{__raw_url__}/resources/stats_default.webp"
+            logger.error(f"Picture path '{sticker_path}' is invalid, replacing with default {url_default}")
+            return url_default
+
     @staticmethod
     def _picture_check_replace(picture_path: str) -> Union[str, bytes]:
         """Check if the given picture path or uri is correct, replace by default if not."""
@@ -427,13 +494,24 @@ class NavigationHandler:
 
     def send_photo(self, picture_path: str, notification: bool = True) -> Optional[telegram.Message]:
         """Send a picture."""
-        picture_obj = self._picture_check_replace(picture_path)
+        picture_obj = self._picture_check_replace(picture_path=picture_path)
         try:
             return self._bot.send_photo(chat_id=self.chat_id, photo=picture_obj, disable_notification=not notification)
         except telegram.error.BadRequest as error:
             logger.error(f"Failed to send picture {picture_path}: {error}")
         return None
 
+    def send_sticker(self, sticker_path: str, notification: bool = True) -> Optional[telegram.Message]:
+        """Send a picture."""
+        sticker_obj = self._sticker_check_replace(sticker_path=sticker_path)
+        try:
+            return self._bot.send_sticker(
+                chat_id=self.chat_id, sticker=sticker_obj, disable_notification=not notification
+            )
+        except telegram.error.BadRequest as error:
+            logger.error(f"Failed to send picture {sticker_path}: {error}")
+        return None
+
     def get_message(self, label_message: str) -> Optional[BaseMessage]:
         """Get message from message_queue matching attribute label_message."""
         return next(iter(x for x in self._message_queue if x.label == label_message), None)
@@ -473,10 +551,8 @@ class NavigationHandler:
             logger.error("Poll is not defined")
             return
 
-        logger.info(
-            f"{self.user_name}'s answer to question '{self._poll.poll.question}' is "
-            f"'{self._poll.poll.options[answer_id].text}'"
-        )
+        answer_ascii = self._poll.poll.options[answer_id].text.encode("ascii", "ignore").decode()
+        logger.info(f"{self.user_name}'s answer to question '{self._poll.poll.question}' is '{answer_ascii}'")
         self._poll_callback(self._poll.poll.options[answer_id].text)
         time.sleep(1)
         self.poll_delete()
